@@ -75,13 +75,16 @@ class ProofServer(socketserver.ThreadingUDPServer):
             raise ServerError("Failed to write status file.")
 
         threading.Thread(
-            target=self.fetch_proofs, daemon=True, name="ServerLoop"
+            target=self.fetch_proofs,
+            daemon=True,
+            name="ServerLoop",
         ).start()
 
     def init_logger(self, level: int, path: Path) -> logging.Logger:
         logger = logging.getLogger(__name__)
         logger.setLevel(level)
         if level != logging.NOTSET:
+            path.mkdir(parents=True, exist_ok=True)
             handler: logging.Handler = RotatingFileHandler(
                 path / consts.LOG_FILE,
                 maxBytes=ProofServer.max_log_bytes,
