@@ -42,8 +42,8 @@ class ProofClient:
 @click.option(
     "--status-path",
     help="Directory to place the status file.",
-    type=ClickPath(exists=True, file_okay=False),
-    default=consts.STATUS_PATH,
+    type=ClickPath(exists=False, file_okay=False),
+    default=consts.DATA_PATH,
 )
 @click.option(
     "-t",
@@ -61,7 +61,10 @@ class ProofClient:
     default=sys.stdout,
 )
 def main(
-    proof: Optional[str], status_path: Path, timeout: float, output: IO[str]
+    proof: Optional[str],
+    status_path: Path,
+    timeout: float,
+    output: IO[str],
 ) -> None:
     status = Status(status_path).read()
     if status is None:
